AppEngine :: appengine-tools-sdk (aka appengine-tools-api) 2.0.21 API

Packages
Package
Description
 
The com.google.appengine.tools package contains the packages that make up the Google App Engine Tools API, which can be embedded in IDEs and other development utilities to perform testing and deployment of App Engine applications.