All Classes and Interfaces

Class
Description
Thrown when an unrecoverable failure occurs while communicating with the remote administration console.
The application administration interface to App Engine.
Settable options for configuring the behavior of update operations.
Creates a new AppAdmin for a designated App Engine application.
Our implementation of the AppAdmin interface.
The command-line SDK tool for administration of App Engine applications.
An App Engine application.
Options used in preparing an application directory for upload.
Generates app.yaml files suitable for uploading as part of a Google App Engine application.
Protobuf type apphosting.tools.devappserver2.CloudSQL
Protobuf type apphosting.tools.devappserver2.CloudSQL
 
Runtime configuration.
Runtime configuration.
 
Describes a single cron entry.
Implementation of the CronEntry interface used to describe a single cron task.
Protobuf type apphosting.tools.devappserver2.CustomConfig
Protobuf type apphosting.tools.devappserver2.CustomConfig
 
The command-line interface for ORM enhancing.
Executes ORM enhancement against jars and class files.
A ClassLoader for the ORM (DataNucleus) enhancer.
An Ant task for ORM enhancement.
Protobuf type apphosting.tools.devappserver2.Environ
Protobuf type apphosting.tools.devappserver2.Environ
 
An App Engine application (may be Java/Python).
Interface describing the application's error handlers.
Protobuf type apphosting.tools.devappserver2.GoConfig
Protobuf type apphosting.tools.devappserver2.GoConfig
 
Simple utility that splits a large jar file into one or more jar files that are each less than the file size specified with --max_file_size.
Protobuf type apphosting.tools.devappserver2.JavaConfig
Protobuf type apphosting.tools.devappserver2.JavaConfig
 
 
 
Launches a process in an operating-system agnostic way.
Protobuf type apphosting.tools.devappserver2.Library
Protobuf type apphosting.tools.devappserver2.Library
 
Runtime configuration required specifically for the Node runtime.
Runtime configuration required specifically for the Node runtime.
 
Pumps lines from one stream onto another, used specifically for getting the stdout/stderr of a child process onto the parent's.
Runtime configuration required specifically for the PHP runtime.
Runtime configuration required specifically for the PHP runtime.
 
Protobuf type apphosting.tools.devappserver2.PythonConfig
Protobuf type apphosting.tools.devappserver2.PythonConfig
 
 
Received by an UpdateListener.
A listener which receives events during a long running operation that involves interaction with the server.
Received by an UpdateListener periodically during an operation to indicate progress.
Received by an UpdateListener.
Utility methods for this package.
Protobuf type apphosting.tools.devappserver2.VMConfig
Protobuf type apphosting.tools.devappserver2.VMConfig