Class AdminException

All Implemented Interfaces:
Serializable

public class AdminException extends RuntimeException
Thrown when an unrecoverable failure occurs while communicating with the remote administration console. This may happen, for example, in case of a network failure. In cases of failure, it may be necessary to rollback the prior application update before attempting another.
See Also:
  • Constructor Details

    • AdminException

      public AdminException(String message, Throwable cause)
    • AdminException

      public AdminException(String message)