Class AppAdminFactory

java.lang.Object
com.google.appengine.tools.admin.AppAdminFactory

public class AppAdminFactory extends Object
Creates a new AppAdmin for a designated App Engine application.
  • Constructor Details

    • AppAdminFactory

      public AppAdminFactory()
  • Method Details

    • createAppAdmin

      public AppAdmin createAppAdmin(Application app, PrintWriter errorWriter)
      Creates a new AppAdmin that can be used to administer the designated App Engine application.
      Parameters:
      app - The application to be administered. May be null.
      errorWriter - A writer to which error logs can be written. The logs can be used for diagnosis if a failure occurs during operation. May be null.
      Returns:
      a not null AppAdmin
    • getAppOptions

      public ApplicationProcessingOptions getAppOptions()
    • setJavaExecutable

      public void setJavaExecutable(File java)
      Specifies the location of a java executable, used when compiling JSPs. By default, the system property java.home is used to identify the currently-running JVM, and if that directory contains a file named bin/java (Unix) or bin\\java.exe (Windows), that is returned.
      Parameters:
      java - the Java executable to be used.
    • setJavaCompiler

      public void setJavaCompiler(File javac)
      Specifies the location of a javac executable, used when compiling JSPs. By default, the system property java.home is used to identify the currently-running JVM. If that pathname ends with "jre", then its parent is used instead as a hoped-for JDK root. If that directory contains a file named bin/javac (Unix) or bin\\javac.exe (Windows), that is returned.
      Parameters:
      javac - the Java compiler executable to be used.
    • setCompileJsps

      public void setCompileJsps(boolean flag)
      Requests that *.jsp files should be compiled into Java byte code, or if false should be left untouched.
      Parameters:
      flag - true to compile .jsp files
    • setDefaultStagingOptions

      public void setDefaultStagingOptions(com.google.apphosting.utils.config.StagingOptions opts)
      Replaces the default staging options to this application options.
      Parameters:
      opts - the new staging options
    • setStagingOptions

      public void setStagingOptions(com.google.apphosting.utils.config.StagingOptions opts)
      Replaces the staging options to this application options.
      Parameters:
      opts - the new staging options
    • setUseAsyncQuickstart

      public void setUseAsyncQuickstart(boolean async)
      Use the Async quickstart generator.
      Parameters:
      async - true uses the async quickstart generator.
    • setUseJava8

      @Deprecated public void setUseJava8(boolean java8)
      Deprecated.
      This method has not effect, and should not be used anymore.
      Use Java8 and Jetty9.
      Parameters:
      java8 - true uses Java8 with Jetty9.
    • setRuntime

      public void setRuntime(String runtime)
      Sets the runtime id to use in the generated app.yaml descriptor.
      Parameters:
      runtime - the runtime id to use.
    • setAllowAnyRuntime

      public void setAllowAnyRuntime(boolean allowAnyRuntime)
      Enables or disables validation of the runtime id provided by the user.
      Parameters:
      allowAnyRuntime - true to allow an arbitrary runtime id value, false to validate it against the list of supported runtimes.
    • setFailOnPrecompilationError

      public void setFailOnPrecompilationError(boolean fail)
      Enables or disables treating (repeated) precompilation errors as fatal when updating an application.
      Parameters:
      fail - true to abort an update if precompilation fails, false to treat it as a warning and continue updating the application.
    • setQuickstart

      public void setQuickstart(boolean enable)