Class ApplicationProcessingOptions

java.lang.Object
com.google.appengine.tools.admin.ApplicationProcessingOptions

public class ApplicationProcessingOptions extends Object
Options used in preparing an application directory for upload.
  • Constructor Details

    • ApplicationProcessingOptions

      public ApplicationProcessingOptions()
  • Method Details

    • getJavaExecutable

      public File getJavaExecutable()
      Returns an appropriate "java" executable. If a prior call to setJavaExecutable(File) was made, that value is returned (on windows, the algorithm is forgiving if ".exe" was omitted, and will add it). If not, the system property java.home is used to identify the currently-running JVM, and if that directory contains a file named bin/java (Unix) or bin\\java.exe (Windows), that is returned.
      Returns:
      the Java executable, as a File.
      Throws:
      IllegalStateException - if the java cannot be found by the heuristic above, but setJavaExecutable(File) has not been called, or if it has been called, but the specified file cannot be found.
    • getJavaCompiler

      public File getJavaCompiler()
      Returns an appropriate "javac" executable. If a prior call to setJavaCompiler(File) was made, that value is returned (on windows, the algorithm is forgiving if ".exe" was omitted, and will add it). If not, the system property java.home is used to identify the currently-running JVM. If that pathname ends with "jre", then its parent is used instead as a hoped-for JDK root. If that directory contains a file named bin/javac (Unix) or bin\\javac.exe (Windows), that is returned.
      Returns:
      the Java compiler, as a File.
      Throws:
      IllegalStateException - if the javac cannot be found by the heuristic above, but setJavaCompiler(File) has not be called, or if it has been called but the file does not exist.
    • isCompileJspsSet

      public boolean isCompileJspsSet()
      Returns whether we should attempt to compile JSPs
    • isBatchModeSet

      public boolean isBatchModeSet()
      Returns whether we should use batch upload
    • setUseAsyncQuickstart

      public void setUseAsyncQuickstart(boolean b)
      Sets whether we should use the Async quickstart generator.
    • isUseAsyncQuickstart

      public boolean isUseAsyncQuickstart()
      Returns whether we should use the Async quickstart generator.
    • setDefaultStagingOptions

      public void setDefaultStagingOptions(com.google.apphosting.utils.config.StagingOptions opts)
      Sets the default staging options.
    • getDefaultStagingOptions

      public com.google.apphosting.utils.config.StagingOptions getDefaultStagingOptions()
      Get the default staging options.
    • setStagingOptions

      public void setStagingOptions(com.google.apphosting.utils.config.StagingOptions opts)
      Sets the staging options.
    • getStagingOptions

      public com.google.apphosting.utils.config.StagingOptions getStagingOptions()
      Get the staging options.
    • setRuntime

      public void setRuntime(String s)
      Sets the runtime id.
    • getRuntime

      public String getRuntime()
      Returns the runtime id.
    • setAllowAnyRuntime

      public void setAllowAnyRuntime(boolean b)
      Sets whether to skip validation of the runtime id provided by the user.
    • isAllowAnyRuntime

      public boolean isAllowAnyRuntime()
      Returns whether to skip validation of the runtime id provided by the user.
    • setFailOnPrecompilationError

      public void setFailOnPrecompilationError(boolean b)
      Sets whether to abort an update in case precompilation fails.
    • isFailOnPrecompilationError

      public boolean isFailOnPrecompilationError()
      Returns whether to abort an update in case precompilation fails.
    • setIgnoreEndpointsFailures

      public void setIgnoreEndpointsFailures(boolean b)
      Sets whether Endpoints config update failures should be ignored.
    • isIgnoreEndpointsFailures

      public boolean isIgnoreEndpointsFailures()
      Return whether Endpoints config update failures should be ignored.
    • setQuickstart

      public void setQuickstart(boolean b)
      Sets whether Quickstart should be applied when staging
    • isQuickstart

      public boolean isQuickstart()
      Return whether Quickstart should be applied when staging
    • setCallerUploadingDispatch

      public void setCallerUploadingDispatch(boolean b)
      Sets whether caller will upload dispatch.xml.