Interface CronEntry

All Known Implementing Classes:
CronEntryImpl

public interface CronEntry
Describes a single cron entry.
  • Method Details

    • getUrl

      String getUrl()
      Returns the application URL invoked by this cron entry.
      Returns:
      the URL from the <url> element in cron.xml
    • getDescription

      String getDescription()
      Returns the human-readable description of this cron entry.
      Returns:
      the text from the <description> element in cron.xml, or null if none was supplied.
    • getSchedule

      String getSchedule()
      Returns the schedule of this cron entry.
      Returns:
      the text from the <schedule> element in cron.xml
    • getTimezone

      String getTimezone()
      Returns the timezone of this cron entry.
      Returns:
      the text from the <schedule> element in cron.xml, or "UTC" as the default value if none was explicitly supplied.
    • getNextTimesIterator

      Iterator<String> getNextTimesIterator()
      Returns an iterator over upcoming execution times. For schedules that are not explicitly fixed to clock time (e.g. "every 12 hours"), the current time will be used by this iterator, whereas time-of-last-update will be used on the production server.
      Returns:
      a new iterator which can be queried for future execution times.
    • toXml

      String toXml()