Class CronEntryImpl.TimeIterator

java.lang.Object
com.google.appengine.tools.admin.CronEntryImpl.TimeIterator
All Implemented Interfaces:
Iterator<String>
Enclosing class:
CronEntryImpl

public class CronEntryImpl.TimeIterator extends Object implements Iterator<String>
An iterator tracking the last execution time, and the groc time specification object to compute future execution times.
  • Constructor Details

    • TimeIterator

      public TimeIterator(Date seedTime, com.google.borg.borgcron.GrocTimeSpecification groc)
  • Method Details