Package com.google.appengine.tools.admin
Class UpdateFailureEvent
java.lang.Object
com.google.appengine.tools.admin.UpdateFailureEvent
Received by an
UpdateListener. This event indicates that an
operation failed.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiongetCause()Returns the cause, if any, for the operation failure.Returns the detailed output from the operation process.Returns the failure message for the operation.
-
Constructor Details
-
UpdateFailureEvent
-
-
Method Details
-
getFailureMessage
Returns the failure message for the operation.- Returns:
- a not
nullmessage.
-
getCause
Returns the cause, if any, for the operation failure.- Returns:
- a
Throwable, ornull.
-
getDetails
Returns the detailed output from the operation process.
-