Package com.google.appengine.tools.admin
package com.google.appengine.tools.admin
-
ClassDescriptionThrown when an unrecoverable failure occurs while communicating with the remote administration console.The application administration interface to App Engine.Settable options for configuring the behavior of update operations.Creates a new
AppAdminfor a designated App Engine application.Our implementation of the AppAdmin interface.The command-line SDK tool for administration of App Engine applications.An App Engine application.Options used in preparing an application directory for upload.Generatesapp.yamlfiles suitable for uploading as part of a Google App Engine application.Describes a single cron entry.Implementation of the CronEntry interface used to describe a single cron task.An App Engine application (may be Java/Python).Interface describing the application's error handlers.Pumps lines from one stream onto another, used specifically for getting the stdout/stderr of a child process onto the parent's.Received by anUpdateListener.A listener which receives events during a long running operation that involves interaction with the server.Received by anUpdateListenerperiodically during an operation to indicate progress.Received by anUpdateListener.Utility methods for this package.