Uses of Package
com.google.appengine.tools.admin
Packages that use com.google.appengine.tools.admin
-
Classes in com.google.appengine.tools.admin used by com.google.appengine.tools.adminClassDescriptionThe application administration interface to App Engine.Creates a new
AppAdminfor a designated App Engine application.An App Engine application.Options used in preparing an application directory for upload.Describes a single cron entry.An App Engine application (may be Java/Python).Interface describing the application's error handlers.Received by anUpdateListener.A listener which receives events during a long running operation that involves interaction with the server.Received by anUpdateListenerperiodically during an operation to indicate progress.Received by anUpdateListener.