java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessageV3
com.google.appengine.tools.development.proto.PhpConfig
All Implemented Interfaces:
PhpConfigOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable

public final class PhpConfig extends com.google.protobuf.GeneratedMessageV3 implements PhpConfigOrBuilder
 Runtime configuration required specifically for the PHP runtime.
 
Protobuf type apphosting.tools.devappserver2.PhpConfig
See Also:
  • Nested Class Summary

    Nested Classes
    Modifier and Type
    Class
    Description
    static final class 
    Runtime configuration required specifically for the PHP runtime.

    Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3

    com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageType extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage,BuilderType extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageType,BuilderType>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageType extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageType extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter

    Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessageLite

    com.google.protobuf.AbstractMessageLite.InternalOneOfEnum
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
     
    static final int
     
    static final com.google.protobuf.Parser<PhpConfig>
    Deprecated.
    static final int
     
    static final int
     
    static final int
     
    static final int
     
    static final int
     

    Fields inherited from class com.google.protobuf.GeneratedMessageV3

    alwaysUseFieldBuilders, unknownFields

    Fields inherited from class com.google.protobuf.AbstractMessage

    memoizedSize

    Fields inherited from class com.google.protobuf.AbstractMessageLite

    memoizedHashCode
  • Method Summary

    Modifier and Type
    Method
    Description
    boolean
     
    static PhpConfig
     
     
    static final com.google.protobuf.Descriptors.Descriptor
     
    boolean
    Enable interactive debugging using XDebug.
    com.google.protobuf.ByteString
    The path to the GAE PHP extension that should be loaded.
    com.google.protobuf.Parser<PhpConfig>
     
    com.google.protobuf.ByteString
    Path to the composer phar
    com.google.protobuf.ByteString
    The path to the PHP executable that should be used.
    com.google.protobuf.ByteString
    Paths to add to LD_LIBRARY_PATH for PHP
    com.google.protobuf.ByteString
    The version of PHP executable.
    int
     
    final com.google.protobuf.UnknownFieldSet
     
    com.google.protobuf.ByteString
    The path to the xdebug extension that should be loaded.
    boolean
    Enable interactive debugging using XDebug.
    boolean
    The path to the GAE PHP extension that should be loaded.
    int
     
    boolean
    Path to the composer phar
    boolean
    The path to the PHP executable that should be used.
    boolean
    Paths to add to LD_LIBRARY_PATH for PHP
    boolean
    The version of PHP executable.
    boolean
    The path to the xdebug extension that should be loaded.
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
     
    final boolean
     
     
    newBuilder(PhpConfig prototype)
     
     
    newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
     
    protected Object
    newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
     
    static PhpConfig
     
    static PhpConfig
    parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)
     
    static PhpConfig
    parseFrom(byte[] data)
     
    static PhpConfig
    parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)
     
    static PhpConfig
    parseFrom(com.google.protobuf.ByteString data)
     
    static PhpConfig
    parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)
     
    static PhpConfig
    parseFrom(com.google.protobuf.CodedInputStream input)
     
    static PhpConfig
    parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)
     
    static PhpConfig
     
    static PhpConfig
    parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)
     
    static PhpConfig
     
    static PhpConfig
    parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)
     
    static com.google.protobuf.Parser<PhpConfig>
     
     
    void
    writeTo(com.google.protobuf.CodedOutputStream output)
     

    Methods inherited from class com.google.protobuf.GeneratedMessageV3

    canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, isStringEmpty, makeExtensionsImmutable, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag

    Methods inherited from class com.google.protobuf.AbstractMessage

    findInitializationErrors, getInitializationErrorString, hashFields, mutableCopy, toString

    Methods inherited from class com.google.protobuf.AbstractMessageLite

    addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo

    Methods inherited from class java.lang.Object

    clone, finalize, getClass, notify, notifyAll, wait, wait, wait

    Methods inherited from interface com.google.protobuf.MessageLite

    toByteArray, toByteString, writeDelimitedTo, writeTo

    Methods inherited from interface com.google.protobuf.MessageOrBuilder

    findInitializationErrors, getAllFields, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof
  • Field Details

    • PHP_EXECUTABLE_PATH_FIELD_NUMBER

      public static final int PHP_EXECUTABLE_PATH_FIELD_NUMBER
      See Also:
    • ENABLE_DEBUGGER_FIELD_NUMBER

      public static final int ENABLE_DEBUGGER_FIELD_NUMBER
      See Also:
    • GAE_EXTENSION_PATH_FIELD_NUMBER

      public static final int GAE_EXTENSION_PATH_FIELD_NUMBER
      See Also:
    • XDEBUG_EXTENSION_PATH_FIELD_NUMBER

      public static final int XDEBUG_EXTENSION_PATH_FIELD_NUMBER
      See Also:
    • PHP_VERSION_FIELD_NUMBER

      public static final int PHP_VERSION_FIELD_NUMBER
      See Also:
    • PHP_LIBRARY_PATH_FIELD_NUMBER

      public static final int PHP_LIBRARY_PATH_FIELD_NUMBER
      See Also:
    • PHP_COMPOSER_PATH_FIELD_NUMBER

      public static final int PHP_COMPOSER_PATH_FIELD_NUMBER
      See Also:
    • PARSER

      @Deprecated public static final com.google.protobuf.Parser<PhpConfig> PARSER
      Deprecated.
  • Method Details

    • newInstance

      protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
      Overrides:
      newInstance in class com.google.protobuf.GeneratedMessageV3
    • getUnknownFields

      public final com.google.protobuf.UnknownFieldSet getUnknownFields()
      Specified by:
      getUnknownFields in interface com.google.protobuf.MessageOrBuilder
      Overrides:
      getUnknownFields in class com.google.protobuf.GeneratedMessageV3
    • getDescriptor

      public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
    • internalGetFieldAccessorTable

      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
      Specified by:
      internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessageV3
    • hasPhpExecutablePath

      public boolean hasPhpExecutablePath()
       The path to the PHP executable that should be used.
       
      optional bytes php_executable_path = 1;
      Specified by:
      hasPhpExecutablePath in interface PhpConfigOrBuilder
      Returns:
      Whether the phpExecutablePath field is set.
    • getPhpExecutablePath

      public com.google.protobuf.ByteString getPhpExecutablePath()
       The path to the PHP executable that should be used.
       
      optional bytes php_executable_path = 1;
      Specified by:
      getPhpExecutablePath in interface PhpConfigOrBuilder
      Returns:
      The phpExecutablePath.
    • hasEnableDebugger

      public boolean hasEnableDebugger()
       Enable interactive debugging using XDebug.
       
      required bool enable_debugger = 3;
      Specified by:
      hasEnableDebugger in interface PhpConfigOrBuilder
      Returns:
      Whether the enableDebugger field is set.
    • getEnableDebugger

      public boolean getEnableDebugger()
       Enable interactive debugging using XDebug.
       
      required bool enable_debugger = 3;
      Specified by:
      getEnableDebugger in interface PhpConfigOrBuilder
      Returns:
      The enableDebugger.
    • hasGaeExtensionPath

      public boolean hasGaeExtensionPath()
       The path to the GAE PHP extension that should be loaded.
       
      optional bytes gae_extension_path = 4;
      Specified by:
      hasGaeExtensionPath in interface PhpConfigOrBuilder
      Returns:
      Whether the gaeExtensionPath field is set.
    • getGaeExtensionPath

      public com.google.protobuf.ByteString getGaeExtensionPath()
       The path to the GAE PHP extension that should be loaded.
       
      optional bytes gae_extension_path = 4;
      Specified by:
      getGaeExtensionPath in interface PhpConfigOrBuilder
      Returns:
      The gaeExtensionPath.
    • hasXdebugExtensionPath

      public boolean hasXdebugExtensionPath()
       The path to the xdebug extension that should be loaded.
       
      optional bytes xdebug_extension_path = 5;
      Specified by:
      hasXdebugExtensionPath in interface PhpConfigOrBuilder
      Returns:
      Whether the xdebugExtensionPath field is set.
    • getXdebugExtensionPath

      public com.google.protobuf.ByteString getXdebugExtensionPath()
       The path to the xdebug extension that should be loaded.
       
      optional bytes xdebug_extension_path = 5;
      Specified by:
      getXdebugExtensionPath in interface PhpConfigOrBuilder
      Returns:
      The xdebugExtensionPath.
    • hasPhpVersion

      public boolean hasPhpVersion()
       The version of PHP executable.
       
      optional bytes php_version = 6;
      Specified by:
      hasPhpVersion in interface PhpConfigOrBuilder
      Returns:
      Whether the phpVersion field is set.
    • getPhpVersion

      public com.google.protobuf.ByteString getPhpVersion()
       The version of PHP executable.
       
      optional bytes php_version = 6;
      Specified by:
      getPhpVersion in interface PhpConfigOrBuilder
      Returns:
      The phpVersion.
    • hasPhpLibraryPath

      public boolean hasPhpLibraryPath()
       Paths to add to LD_LIBRARY_PATH for PHP
       
      optional bytes php_library_path = 7;
      Specified by:
      hasPhpLibraryPath in interface PhpConfigOrBuilder
      Returns:
      Whether the phpLibraryPath field is set.
    • getPhpLibraryPath

      public com.google.protobuf.ByteString getPhpLibraryPath()
       Paths to add to LD_LIBRARY_PATH for PHP
       
      optional bytes php_library_path = 7;
      Specified by:
      getPhpLibraryPath in interface PhpConfigOrBuilder
      Returns:
      The phpLibraryPath.
    • hasPhpComposerPath

      public boolean hasPhpComposerPath()
       Path to the composer phar
       
      optional bytes php_composer_path = 8;
      Specified by:
      hasPhpComposerPath in interface PhpConfigOrBuilder
      Returns:
      Whether the phpComposerPath field is set.
    • getPhpComposerPath

      public com.google.protobuf.ByteString getPhpComposerPath()
       Path to the composer phar
       
      optional bytes php_composer_path = 8;
      Specified by:
      getPhpComposerPath in interface PhpConfigOrBuilder
      Returns:
      The phpComposerPath.
    • isInitialized

      public final boolean isInitialized()
      Specified by:
      isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
      Overrides:
      isInitialized in class com.google.protobuf.GeneratedMessageV3
    • writeTo

      public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException
      Specified by:
      writeTo in interface com.google.protobuf.MessageLite
      Overrides:
      writeTo in class com.google.protobuf.GeneratedMessageV3
      Throws:
      IOException
    • getSerializedSize

      public int getSerializedSize()
      Specified by:
      getSerializedSize in interface com.google.protobuf.MessageLite
      Overrides:
      getSerializedSize in class com.google.protobuf.GeneratedMessageV3
    • equals

      public boolean equals(Object obj)
      Specified by:
      equals in interface com.google.protobuf.Message
      Overrides:
      equals in class com.google.protobuf.AbstractMessage
    • hashCode

      public int hashCode()
      Specified by:
      hashCode in interface com.google.protobuf.Message
      Overrides:
      hashCode in class com.google.protobuf.AbstractMessage
    • parseFrom

      public static PhpConfig parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static PhpConfig parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static PhpConfig parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static PhpConfig parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static PhpConfig parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static PhpConfig parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static PhpConfig parseFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static PhpConfig parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static PhpConfig parseDelimitedFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static PhpConfig parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseFrom

      public static PhpConfig parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static PhpConfig parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • newBuilderForType

      public PhpConfig.Builder newBuilderForType()
      Specified by:
      newBuilderForType in interface com.google.protobuf.Message
      Specified by:
      newBuilderForType in interface com.google.protobuf.MessageLite
    • newBuilder

      public static PhpConfig.Builder newBuilder()
    • newBuilder

      public static PhpConfig.Builder newBuilder(PhpConfig prototype)
    • toBuilder

      public PhpConfig.Builder toBuilder()
      Specified by:
      toBuilder in interface com.google.protobuf.Message
      Specified by:
      toBuilder in interface com.google.protobuf.MessageLite
    • newBuilderForType

      protected PhpConfig.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
      Specified by:
      newBuilderForType in class com.google.protobuf.GeneratedMessageV3
    • getDefaultInstance

      public static PhpConfig getDefaultInstance()
    • parser

      public static com.google.protobuf.Parser<PhpConfig> parser()
    • getParserForType

      public com.google.protobuf.Parser<PhpConfig> getParserForType()
      Specified by:
      getParserForType in interface com.google.protobuf.Message
      Specified by:
      getParserForType in interface com.google.protobuf.MessageLite
      Overrides:
      getParserForType in class com.google.protobuf.GeneratedMessageV3
    • getDefaultInstanceForType

      public PhpConfig getDefaultInstanceForType()
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder