Class PythonConfig.Builder
java.lang.Object
com.google.protobuf.AbstractMessageLite.Builder
com.google.protobuf.AbstractMessage.Builder<BuilderType>
com.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
com.google.appengine.tools.development.proto.PythonConfig.Builder
- All Implemented Interfaces:
PythonConfigOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Cloneable
- Enclosing class:
- PythonConfig
public static final class PythonConfig.Builder
extends com.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
implements PythonConfigOrBuilder
Protobuf type
apphosting.tools.devappserver2.PythonConfig-
Method Summary
Modifier and TypeMethodDescriptionaddRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, Object value) build()clear()clearField(com.google.protobuf.Descriptors.FieldDescriptor field) clearOneof(com.google.protobuf.Descriptors.OneofDescriptor oneof) An argument that will be provided to the script specified in startup_script.The path to a Python script that will be executed using execfile before the runtime executes user code.clone()static final com.google.protobuf.Descriptors.Descriptorcom.google.protobuf.Descriptors.DescriptorAn argument that will be provided to the script specified in startup_script.com.google.protobuf.ByteStringAn argument that will be provided to the script specified in startup_script.The path to a Python script that will be executed using execfile before the runtime executes user code.com.google.protobuf.ByteStringThe path to a Python script that will be executed using execfile before the runtime executes user code.booleanAn argument that will be provided to the script specified in startup_script.booleanThe path to a Python script that will be executed using execfile before the runtime executes user code.protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTablefinal booleanmergeFrom(PythonConfig other) mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) mergeFrom(com.google.protobuf.Message other) final PythonConfig.BuildermergeUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields) setRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, int index, Object value) setStartupArgs(String value) An argument that will be provided to the script specified in startup_script.setStartupArgsBytes(com.google.protobuf.ByteString value) An argument that will be provided to the script specified in startup_script.setStartupScript(String value) The path to a Python script that will be executed using execfile before the runtime executes user code.setStartupScriptBytes(com.google.protobuf.ByteString value) The path to a Python script that will be executed using execfile before the runtime executes user code.final PythonConfig.BuildersetUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields) Methods inherited from class com.google.protobuf.GeneratedMessageV3.Builder
getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMutableMapField, isClean, markClean, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setUnknownFieldSetBuilder, setUnknownFieldsProto3Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toStringMethods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageExceptionMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface com.google.protobuf.Message.Builder
mergeDelimitedFrom, mergeDelimitedFromMethods inherited from interface com.google.protobuf.MessageLite.Builder
mergeFromMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Method Details
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() -
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
clear
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
getDefaultInstanceForType
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
clone
- Specified by:
clonein interfacecom.google.protobuf.Message.Builder- Specified by:
clonein interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clonein classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
setField
public PythonConfig.Builder setField(com.google.protobuf.Descriptors.FieldDescriptor field, Object value) - Specified by:
setFieldin interfacecom.google.protobuf.Message.Builder- Overrides:
setFieldin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
clearField
- Specified by:
clearFieldin interfacecom.google.protobuf.Message.Builder- Overrides:
clearFieldin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
clearOneof
- Specified by:
clearOneofin interfacecom.google.protobuf.Message.Builder- Overrides:
clearOneofin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
setRepeatedField
public PythonConfig.Builder setRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, int index, Object value) - Specified by:
setRepeatedFieldin interfacecom.google.protobuf.Message.Builder- Overrides:
setRepeatedFieldin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
addRepeatedField
public PythonConfig.Builder addRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, Object value) - Specified by:
addRepeatedFieldin interfacecom.google.protobuf.Message.Builder- Overrides:
addRepeatedFieldin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
mergeFrom
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<PythonConfig.Builder>
-
mergeFrom
-
isInitialized
public final boolean isInitialized()- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
mergeFrom
public PythonConfig.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<PythonConfig.Builder>- Throws:
IOException
-
hasStartupScript
public boolean hasStartupScript()The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Specified by:
hasStartupScriptin interfacePythonConfigOrBuilder- Returns:
- Whether the startupScript field is set.
-
getStartupScript
The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Specified by:
getStartupScriptin interfacePythonConfigOrBuilder- Returns:
- The startupScript.
-
getStartupScriptBytes
public com.google.protobuf.ByteString getStartupScriptBytes()The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Specified by:
getStartupScriptBytesin interfacePythonConfigOrBuilder- Returns:
- The bytes for startupScript.
-
setStartupScript
The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Parameters:
value- The startupScript to set.- Returns:
- This builder for chaining.
-
clearStartupScript
The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Returns:
- This builder for chaining.
-
setStartupScriptBytes
The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Parameters:
value- The bytes for startupScript to set.- Returns:
- This builder for chaining.
-
hasStartupArgs
public boolean hasStartupArgs()An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Specified by:
hasStartupArgsin interfacePythonConfigOrBuilder- Returns:
- Whether the startupArgs field is set.
-
getStartupArgs
An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Specified by:
getStartupArgsin interfacePythonConfigOrBuilder- Returns:
- The startupArgs.
-
getStartupArgsBytes
public com.google.protobuf.ByteString getStartupArgsBytes()An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Specified by:
getStartupArgsBytesin interfacePythonConfigOrBuilder- Returns:
- The bytes for startupArgs.
-
setStartupArgs
An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Parameters:
value- The startupArgs to set.- Returns:
- This builder for chaining.
-
clearStartupArgs
An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Returns:
- This builder for chaining.
-
setStartupArgsBytes
An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Parameters:
value- The bytes for startupArgs to set.- Returns:
- This builder for chaining.
-
setUnknownFields
public final PythonConfig.Builder setUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields) - Specified by:
setUnknownFieldsin interfacecom.google.protobuf.Message.Builder- Overrides:
setUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-
mergeUnknownFields
public final PythonConfig.Builder mergeUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields) - Specified by:
mergeUnknownFieldsin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3.Builder<PythonConfig.Builder>
-