Interface PythonConfigOrBuilder

All Superinterfaces:
com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder
All Known Implementing Classes:
PythonConfig, PythonConfig.Builder

public interface PythonConfigOrBuilder extends com.google.protobuf.MessageOrBuilder
  • Method Summary

    Modifier and Type
    Method
    Description
    An argument that will be provided to the script specified in startup_script.
    com.google.protobuf.ByteString
    An argument that will be provided to the script specified in startup_script.
    The path to a Python script that will be executed using execfile before the runtime executes user code.
    com.google.protobuf.ByteString
    The path to a Python script that will be executed using execfile before the runtime executes user code.
    boolean
    An argument that will be provided to the script specified in startup_script.
    boolean
    The path to a Python script that will be executed using execfile before the runtime executes user code.

    Methods inherited from interface com.google.protobuf.MessageLiteOrBuilder

    isInitialized

    Methods inherited from interface com.google.protobuf.MessageOrBuilder

    findInitializationErrors, getAllFields, getDefaultInstanceForType, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
  • Method Details

    • hasStartupScript

      boolean hasStartupScript()
       The path to a Python script that will be executed using execfile before
       the runtime executes user code. Meant for tools such as debuggers.
       
      optional string startup_script = 1;
      Returns:
      Whether the startupScript field is set.
    • getStartupScript

      String getStartupScript()
       The path to a Python script that will be executed using execfile before
       the runtime executes user code. Meant for tools such as debuggers.
       
      optional string startup_script = 1;
      Returns:
      The startupScript.
    • getStartupScriptBytes

      com.google.protobuf.ByteString getStartupScriptBytes()
       The path to a Python script that will be executed using execfile before
       the runtime executes user code. Meant for tools such as debuggers.
       
      optional string startup_script = 1;
      Returns:
      The bytes for startupScript.
    • hasStartupArgs

      boolean hasStartupArgs()
       An argument that will be provided to the script specified in
       startup_script.
       
      optional string startup_args = 2;
      Returns:
      Whether the startupArgs field is set.
    • getStartupArgs

      String getStartupArgs()
       An argument that will be provided to the script specified in
       startup_script.
       
      optional string startup_args = 2;
      Returns:
      The startupArgs.
    • getStartupArgsBytes

      com.google.protobuf.ByteString getStartupArgsBytes()
       An argument that will be provided to the script specified in
       startup_script.
       
      optional string startup_args = 2;
      Returns:
      The bytes for startupArgs.