Uses of Class
com.google.appengine.tools.development.proto.PythonConfig.Builder
Packages that use PythonConfig.Builder
-
Uses of PythonConfig.Builder in com.google.appengine.tools.development.proto
Methods in com.google.appengine.tools.development.proto that return PythonConfig.BuilderModifier and TypeMethodDescriptionPythonConfig.Builder.addRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, Object value) PythonConfig.Builder.clear()PythonConfig.Builder.clearField(com.google.protobuf.Descriptors.FieldDescriptor field) PythonConfig.Builder.clearOneof(com.google.protobuf.Descriptors.OneofDescriptor oneof) PythonConfig.Builder.clearStartupArgs()An argument that will be provided to the script specified in startup_script.PythonConfig.Builder.clearStartupScript()The path to a Python script that will be executed using execfile before the runtime executes user code.PythonConfig.Builder.clone()Config.Builder.getPythonConfigBuilder()optional .apphosting.tools.devappserver2.PythonConfig python_config = 14;PythonConfig.Builder.mergeFrom(PythonConfig other) PythonConfig.Builder.mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) PythonConfig.Builder.mergeFrom(com.google.protobuf.Message other) final PythonConfig.BuilderPythonConfig.Builder.mergeUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields) static PythonConfig.BuilderPythonConfig.newBuilder()static PythonConfig.BuilderPythonConfig.newBuilder(PythonConfig prototype) PythonConfig.newBuilderForType()protected PythonConfig.BuilderPythonConfig.newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent) PythonConfig.Builder.setRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, int index, Object value) PythonConfig.Builder.setStartupArgs(String value) An argument that will be provided to the script specified in startup_script.PythonConfig.Builder.setStartupArgsBytes(com.google.protobuf.ByteString value) An argument that will be provided to the script specified in startup_script.PythonConfig.Builder.setStartupScript(String value) The path to a Python script that will be executed using execfile before the runtime executes user code.PythonConfig.Builder.setStartupScriptBytes(com.google.protobuf.ByteString value) The path to a Python script that will be executed using execfile before the runtime executes user code.final PythonConfig.BuilderPythonConfig.Builder.setUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields) PythonConfig.toBuilder()Methods in com.google.appengine.tools.development.proto with parameters of type PythonConfig.BuilderModifier and TypeMethodDescriptionConfig.Builder.setPythonConfig(PythonConfig.Builder builderForValue) optional .apphosting.tools.devappserver2.PythonConfig python_config = 14;