Class Enhancer
java.lang.Object
com.google.appengine.tools.enhancer.Enhancer
Executes ORM enhancement against jars and class files.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidexecute()Runs enhancement.voidSets arguments to be passed to the underlying enhancer.voidsetDatanucleusVersion(String datanucleusVersion) Sets the version of datanucleus to use for enhancement.voidsetTargets(Set<URL> enhanceTargets) Sets the class files and jar files which will be enhanced.
-
Constructor Details
-
Enhancer
public Enhancer()
-
-
Method Details
-
setTargets
Sets the class files and jar files which will be enhanced.- Parameters:
enhanceTargets- must not be null
-
setArgs
Sets arguments to be passed to the underlying enhancer.- Parameters:
args- must not be null
-
setDatanucleusVersion
Sets the version of datanucleus to use for enhancement. Specifically, this is the directory under/lib/opt/tools/datanucleus containing the enhancer and the jars it depends on. - Parameters:
datanucleusVersion- must not be null
-
execute
public void execute()Runs enhancement.
-