Class EnhancerTask

java.lang.Object
org.apache.tools.ant.ProjectComponent
org.apache.tools.ant.Task
org.apache.tools.ant.taskdefs.Java
com.google.appengine.tools.enhancer.EnhancerTask
All Implemented Interfaces:
Cloneable

public class EnhancerTask extends org.apache.tools.ant.taskdefs.Java
An Ant task for ORM enhancement.

In order to use this task, users must install a taskdef in Ant:

   <taskdef name="enhancer" classpathref="appengine-sdk-classpath" 
       classname="com.google.appengine.tools.development.enhancer.EnhancerTask"/>
 
Where appengine-sdk-classpath includes appengine-tools-api.jar.

Options for this task are documented on DataNucleus' web site.

  • Field Summary

    Fields inherited from class org.apache.tools.ant.taskdefs.Java

    redirector, redirectorElement

    Fields inherited from class org.apache.tools.ant.Task

    target, taskName, taskType, wrapper

    Fields inherited from class org.apache.tools.ant.ProjectComponent

    description, location, project
  • Constructor Summary

    Constructors
    Constructor
    Description
    Default constructor
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    addFileSet(org.apache.tools.ant.types.FileSet fs)
    Add a fileset.
    void
    Execution method
    Gets the root dir for looking for files
    protected File[]
     
    void
    set API Adapter
    void
    setCheckonly(boolean checkonly)
    Whether to just check the enhancement state
    void
    set output directory
    void
    setDir(File dir)
    Sets the root dir for looking for files
    void
    Set the symbolic name of the ClassEnhancer to use
    void
    Set one or more file suffixes for the input files.
    void
    setIf(String ifpropertyset)
    Executes this task only if the property is set
    void
    Set the persistence-unit name to enhance
    void
    setVerbose(boolean verbose)
    set verbose

    Methods inherited from class org.apache.tools.ant.taskdefs.Java

    addAssertions, addConfiguredRedirector, addEnv, addSysproperty, addSyspropertyset, checkConfiguration, clearArgs, createArg, createBootclasspath, createClasspath, createJvmarg, createModulepath, createPermissions, createUpgrademodulepath, createWatchdog, executeJava, executeJava, getCommandLine, getSysProperties, handleErrorFlush, handleErrorOutput, handleFlush, handleInput, handleOutput, maybeSetResultPropertyValue, run, setAppend, setArgs, setClassname, setClasspath, setClasspathRef, setCloneVm, setDiscardError, setDiscardOutput, setError, setErrorProperty, setFailonerror, setFork, setInput, setInputString, setJar, setJvm, setJvmargs, setJVMVersion, setLogError, setMaxmemory, setModule, setModulepath, setModulepathRef, setNewenvironment, setOutput, setOutputproperty, setResultProperty, setSourceFile, setSpawn, setTimeout, setupRedirector

    Methods inherited from class org.apache.tools.ant.Task

    bindToOwner, getOwningTarget, getRuntimeConfigurableWrapper, getTaskName, getTaskType, getWrapper, init, isInvalid, log, log, log, log, maybeConfigure, perform, reconfigure, setOwningTarget, setRuntimeConfigurableWrapper, setTaskName, setTaskType

    Methods inherited from class org.apache.tools.ant.ProjectComponent

    clone, getDescription, getLocation, getProject, setDescription, setLocation, setProject

    Methods inherited from class java.lang.Object

    equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • EnhancerTask

      public EnhancerTask()
      Default constructor
  • Method Details

    • execute

      public void execute() throws org.apache.tools.ant.BuildException
      Execution method
      Overrides:
      execute in class org.apache.tools.ant.taskdefs.Java
      Throws:
      org.apache.tools.ant.BuildException - Thrown when an error occurs when processing the task
    • setCheckonly

      public void setCheckonly(boolean checkonly)
      Whether to just check the enhancement state
      Parameters:
      checkonly - Whether to just check
    • setDestination

      public void setDestination(File destdir)
      set output directory
      Parameters:
      destdir - output dir
    • setApi

      public void setApi(String api)
      set API Adapter
      Parameters:
      api - API Adapter
    • setEnhancerName

      public void setEnhancerName(String enhancer)
      Set the symbolic name of the ClassEnhancer to use
      Parameters:
      enhancer - Class Enhancer to use
    • setPersistenceUnit

      public void setPersistenceUnit(String unit)
      Set the persistence-unit name to enhance
      Parameters:
      unit - Name of the persistence-unit to enhance
    • setDir

      public void setDir(File dir)
      Sets the root dir for looking for files
      Overrides:
      setDir in class org.apache.tools.ant.taskdefs.Java
      Parameters:
      dir - the root dir
    • getDir

      public File getDir()
      Gets the root dir for looking for files
      Returns:
      the root dir
    • setFileSuffixes

      public void setFileSuffixes(String suffixes)
      Set one or more file suffixes for the input files. Suffixes are separated with a comma(,)
      Parameters:
      suffixes - the suffices
    • setVerbose

      public void setVerbose(boolean verbose)
      set verbose
      Parameters:
      verbose - Whether to give verbose output
    • addFileSet

      public void addFileSet(org.apache.tools.ant.types.FileSet fs)
      Add a fileset. @see ant manual
      Parameters:
      fs - the FileSet
    • getFiles

      protected File[] getFiles()
    • setIf

      public void setIf(String ifpropertyset)
      Executes this task only if the property is set