Package com.google.appengine.tools.admin
Interface AppAdmin
- All Known Implementing Classes:
AppAdminImpl
public interface AppAdmin
The application administration interface to App Engine. Use this
API to update, configure, and otherwise manage an App Engine
application. Use
AppAdminFactory to retrieve an AppAdmin
instance configured for a specific application.
Synchronous versus Asynchronous requests:
Some requests, such as #update, occur asynchronously
and must be monitored with a listener. Other requests, such as
#updateIndexes, are made synchronously. In either case,
work often continues to occur asynchronously on the remote server after the
request has been completed.
Error handling: Most configuration operations that communicate
with App Engine's remote administration server use a
network connection. In cases where unrecoverable failures occur (such as a
network failure), this API throws an
AdminException.
Application updates occur transactionally. If a failure occurs during
update, you must #rollback the incomplete transaction before
beginning another.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic classSettable options for configuring the behavior of update operations. -
Method Summary
Modifier and TypeMethodDescriptionvoidstageApplicationWithDefaultResourceLimits(File stagingDir) Stage an application directory with default resource limitsvoidstageApplicationWithRemoteResourceLimits(File stagingDir) Stage an application directory with remote resource limits
-
Method Details
-
stageApplicationWithDefaultResourceLimits
Stage an application directory with default resource limits -
stageApplicationWithRemoteResourceLimits
Stage an application directory with remote resource limits
-