Package com.google.appengine.tools.admin
Class AppAdminFactory
java.lang.Object
com.google.appengine.tools.admin.AppAdminFactory
Creates a new
AppAdmin for a designated App Engine application.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncreateAppAdmin(Application app, PrintWriter errorWriter) Creates a newAppAdminthat can be used to administer the designated App Engine application.voidsetAllowAnyRuntime(boolean allowAnyRuntime) Enables or disables validation of the runtime id provided by the user.voidsetCompileJsps(boolean flag) Requests that *.jsp files should be compiled into Java byte code, or if false should be left untouched.voidsetDefaultStagingOptions(com.google.apphosting.utils.config.StagingOptions opts) Replaces the default staging options to this application options.voidsetFailOnPrecompilationError(boolean fail) Enables or disables treating (repeated) precompilation errors as fatal when updating an application.voidsetJavaCompiler(File javac) Specifies the location of a javac executable, used when compiling JSPs.voidsetJavaExecutable(File java) Specifies the location of a java executable, used when compiling JSPs.voidsetQuickstart(boolean enable) voidsetRuntime(String runtime) Sets the runtime id to use in the generated app.yaml descriptor.voidsetStagingOptions(com.google.apphosting.utils.config.StagingOptions opts) Replaces the staging options to this application options.voidsetUseAsyncQuickstart(boolean async) Use the Async quickstart generator.voidsetUseJava8(boolean java8) Deprecated.This method has not effect, and should not be used anymore.
-
Constructor Details
-
AppAdminFactory
public AppAdminFactory()
-
-
Method Details
-
createAppAdmin
Creates a newAppAdminthat can be used to administer the designated App Engine application.- Parameters:
app- The application to be administered. May benull.errorWriter- A writer to which error logs can be written. The logs can be used for diagnosis if a failure occurs during operation. May benull.- Returns:
- a not
nullAppAdmin
-
getAppOptions
-
setJavaExecutable
Specifies the location of a java executable, used when compiling JSPs. By default, the system propertyjava.homeis used to identify the currently-running JVM, and if that directory contains a file namedbin/java(Unix) orbin\\java.exe(Windows), that is returned.- Parameters:
java- the Java executable to be used.
-
setJavaCompiler
Specifies the location of a javac executable, used when compiling JSPs. By default, the system propertyjava.homeis used to identify the currently-running JVM. If that pathname ends with "jre", then its parent is used instead as a hoped-for JDK root. If that directory contains a file namedbin/javac(Unix) orbin\\javac.exe(Windows), that is returned.- Parameters:
javac- the Java compiler executable to be used.
-
setCompileJsps
public void setCompileJsps(boolean flag) Requests that *.jsp files should be compiled into Java byte code, or if false should be left untouched.- Parameters:
flag-trueto compile .jsp files
-
setDefaultStagingOptions
public void setDefaultStagingOptions(com.google.apphosting.utils.config.StagingOptions opts) Replaces the default staging options to this application options.- Parameters:
opts- the new staging options
-
setStagingOptions
public void setStagingOptions(com.google.apphosting.utils.config.StagingOptions opts) Replaces the staging options to this application options.- Parameters:
opts- the new staging options
-
setUseAsyncQuickstart
public void setUseAsyncQuickstart(boolean async) Use the Async quickstart generator.- Parameters:
async-trueuses the async quickstart generator.
-
setUseJava8
Deprecated.This method has not effect, and should not be used anymore.Use Java8 and Jetty9.- Parameters:
java8-trueuses Java8 with Jetty9.
-
setRuntime
Sets the runtime id to use in the generated app.yaml descriptor.- Parameters:
runtime- the runtime id to use.
-
setAllowAnyRuntime
public void setAllowAnyRuntime(boolean allowAnyRuntime) Enables or disables validation of the runtime id provided by the user.- Parameters:
allowAnyRuntime-trueto allow an arbitrary runtime id value,falseto validate it against the list of supported runtimes.
-
setFailOnPrecompilationError
public void setFailOnPrecompilationError(boolean fail) Enables or disables treating (repeated) precompilation errors as fatal when updating an application.- Parameters:
fail-trueto abort an update if precompilation fails,falseto treat it as a warning and continue updating the application.
-
setQuickstart
public void setQuickstart(boolean enable)
-