Package com.google.appengine.tools.admin
Class ApplicationProcessingOptions
java.lang.Object
com.google.appengine.tools.admin.ApplicationProcessingOptions
Options used in preparing an application directory for upload.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncom.google.apphosting.utils.config.StagingOptionsGet the default staging options.Returns an appropriate "javac" executable.Returns an appropriate "java" executable.Returns the runtime id.com.google.apphosting.utils.config.StagingOptionsGet the staging options.booleanReturns whether to skip validation of the runtime id provided by the user.booleanReturns whether we should use batch uploadbooleanReturns whether we should attempt to compile JSPsbooleanReturns whether to abort an update in case precompilation fails.booleanReturn whether Endpoints config update failures should be ignored.booleanReturn whether Quickstart should be applied when stagingbooleanReturns whether we should use the Async quickstart generator.voidsetAllowAnyRuntime(boolean b) Sets whether to skip validation of the runtime id provided by the user.voidsetCallerUploadingDispatch(boolean b) Sets whether caller will upload dispatch.xml.voidsetDefaultStagingOptions(com.google.apphosting.utils.config.StagingOptions opts) Sets the default staging options.voidsetFailOnPrecompilationError(boolean b) Sets whether to abort an update in case precompilation fails.voidsetIgnoreEndpointsFailures(boolean b) Sets whether Endpoints config update failures should be ignored.voidsetQuickstart(boolean b) Sets whether Quickstart should be applied when stagingvoidsetRuntime(String s) Sets the runtime id.voidsetStagingOptions(com.google.apphosting.utils.config.StagingOptions opts) Sets the staging options.voidsetUseAsyncQuickstart(boolean b) Sets whether we should use the Async quickstart generator.
-
Constructor Details
-
ApplicationProcessingOptions
public ApplicationProcessingOptions()
-
-
Method Details
-
getJavaExecutable
Returns an appropriate "java" executable. If a prior call tosetJavaExecutable(File)was made, that value is returned (on windows, the algorithm is forgiving if ".exe" was omitted, and will add it). If not, the system propertyjava.homeis used to identify the currently-running JVM, and if that directory contains a file namedbin/java(Unix) orbin\\java.exe(Windows), that is returned.- Returns:
- the Java executable, as a
File. - Throws:
IllegalStateException- if the java cannot be found by the heuristic above, butsetJavaExecutable(File)has not been called, or if it has been called, but the specified file cannot be found.
-
getJavaCompiler
Returns an appropriate "javac" executable. If a prior call tosetJavaCompiler(File)was made, that value is returned (on windows, the algorithm is forgiving if ".exe" was omitted, and will add it). If not, the system propertyjava.homeis used to identify the currently-running JVM. If that pathname ends with "jre", then its parent is used instead as a hoped-for JDK root. If that directory contains a file namedbin/javac(Unix) orbin\\javac.exe(Windows), that is returned.- Returns:
- the Java compiler, as a
File. - Throws:
IllegalStateException- if the javac cannot be found by the heuristic above, butsetJavaCompiler(File)has not be called, or if it has been called but the file does not exist.
-
isCompileJspsSet
public boolean isCompileJspsSet()Returns whether we should attempt to compile JSPs -
isBatchModeSet
public boolean isBatchModeSet()Returns whether we should use batch upload -
setUseAsyncQuickstart
public void setUseAsyncQuickstart(boolean b) Sets whether we should use the Async quickstart generator. -
isUseAsyncQuickstart
public boolean isUseAsyncQuickstart()Returns whether we should use the Async quickstart generator. -
setDefaultStagingOptions
public void setDefaultStagingOptions(com.google.apphosting.utils.config.StagingOptions opts) Sets the default staging options. -
getDefaultStagingOptions
public com.google.apphosting.utils.config.StagingOptions getDefaultStagingOptions()Get the default staging options. -
setStagingOptions
public void setStagingOptions(com.google.apphosting.utils.config.StagingOptions opts) Sets the staging options. -
getStagingOptions
public com.google.apphosting.utils.config.StagingOptions getStagingOptions()Get the staging options. -
setRuntime
Sets the runtime id. -
getRuntime
Returns the runtime id. -
setAllowAnyRuntime
public void setAllowAnyRuntime(boolean b) Sets whether to skip validation of the runtime id provided by the user. -
isAllowAnyRuntime
public boolean isAllowAnyRuntime()Returns whether to skip validation of the runtime id provided by the user. -
setFailOnPrecompilationError
public void setFailOnPrecompilationError(boolean b) Sets whether to abort an update in case precompilation fails. -
isFailOnPrecompilationError
public boolean isFailOnPrecompilationError()Returns whether to abort an update in case precompilation fails. -
setIgnoreEndpointsFailures
public void setIgnoreEndpointsFailures(boolean b) Sets whether Endpoints config update failures should be ignored. -
isIgnoreEndpointsFailures
public boolean isIgnoreEndpointsFailures()Return whether Endpoints config update failures should be ignored. -
setQuickstart
public void setQuickstart(boolean b) Sets whether Quickstart should be applied when staging -
isQuickstart
public boolean isQuickstart()Return whether Quickstart should be applied when staging -
setCallerUploadingDispatch
public void setCallerUploadingDispatch(boolean b) Sets whether caller will upload dispatch.xml.
-