Interface ConfigOrBuilder
- All Superinterfaces:
com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder
- All Known Implementing Classes:
Config,Config.Builder
public interface ConfigOrBuilder
extends com.google.protobuf.MessageOrBuilder
-
Method Summary
Modifier and TypeMethodDescriptionThe host name to which to connect to send API requests.com.google.protobuf.ByteStringThe host name to which to connect to send API requests.intThe port on which to connect to send API requests.com.google.protobuf.ByteStringgetAppId()The app id of the app to be run.com.google.protobuf.ByteStringThe path to the root of the application.required string auth_domain = 16;com.google.protobuf.ByteStringrequired string auth_domain = 16;optional .apphosting.tools.devappserver2.CloudSQL cloud_sql_config = 11;optional .apphosting.tools.devappserver2.CloudSQL cloud_sql_config = 11;optional .apphosting.tools.devappserver2.CustomConfig custom_config = 23;optional .apphosting.tools.devappserver2.CustomConfig custom_config = 23;required string datacenter = 12;com.google.protobuf.ByteStringrequired string datacenter = 12;getEnviron(int index) Extra user-specified environment variables.intExtra user-specified environment variables.Extra user-specified environment variables.getEnvironOrBuilder(int index) Extra user-specified environment variables.List<? extends EnvironOrBuilder>Extra user-specified environment variables.optional .apphosting.tools.devappserver2.GoConfig go_config = 25;optional .apphosting.tools.devappserver2.GoConfig go_config = 25;getGrpcApis(int index) repeated string grpc_apis = 24;com.google.protobuf.ByteStringgetGrpcApisBytes(int index) repeated string grpc_apis = 24;intrepeated string grpc_apis = 24;repeated string grpc_apis = 24;required string instance_id = 13;com.google.protobuf.ByteStringrequired string instance_id = 13;optional .apphosting.tools.devappserver2.JavaConfig java_config = 21;optional .apphosting.tools.devappserver2.JavaConfig java_config = 21;getLibraries(int index) Libraries enabled for the application.intLibraries enabled for the application.Libraries enabled for the application.getLibrariesOrBuilder(int index) Libraries enabled for the application.List<? extends LibraryOrBuilder>Libraries enabled for the application.intoptional int32 max_instances = 18;optional .apphosting.tools.devappserver2.NodeConfig node_config = 26;optional .apphosting.tools.devappserver2.NodeConfig node_config = 26;optional .apphosting.tools.devappserver2.PhpConfig php_config = 9;optional .apphosting.tools.devappserver2.PhpConfig php_config = 9;optional .apphosting.tools.devappserver2.PythonConfig python_config = 14;optional .apphosting.tools.devappserver2.PythonConfig python_config = 14;intThe port of the cloud SDK development server.A regex for files to skip.com.google.protobuf.ByteStringA regex for files to skip.A regex for files used for static handlers.com.google.protobuf.ByteStringA regex for files used for static handlers.longThe logging level at which logs should be written to stderr: 0 - Debug 1 - Info 2 - Warning 3 - Error 4 - CriticalbooleanWhether the application has threadsafe enabled.com.google.protobuf.ByteStringThe version id of the app to be run.booleangetVm()optional bool vm = 22 [default = false];optional .apphosting.tools.devappserver2.VMConfig vm_config = 19;optional .apphosting.tools.devappserver2.VMConfig vm_config = 19;booleanThe host name to which to connect to send API requests.booleanThe port on which to connect to send API requests.booleanhasAppId()The app id of the app to be run.booleanThe path to the root of the application.booleanrequired string auth_domain = 16;booleanoptional .apphosting.tools.devappserver2.CloudSQL cloud_sql_config = 11;booleanoptional .apphosting.tools.devappserver2.CustomConfig custom_config = 23;booleanrequired string datacenter = 12;booleanoptional .apphosting.tools.devappserver2.GoConfig go_config = 25;booleanrequired string instance_id = 13;booleanoptional .apphosting.tools.devappserver2.JavaConfig java_config = 21;booleanoptional int32 max_instances = 18;booleanoptional .apphosting.tools.devappserver2.NodeConfig node_config = 26;booleanoptional .apphosting.tools.devappserver2.PhpConfig php_config = 9;booleanoptional .apphosting.tools.devappserver2.PythonConfig python_config = 14;booleanThe port of the cloud SDK development server.booleanA regex for files to skip.booleanA regex for files used for static handlers.booleanThe logging level at which logs should be written to stderr: 0 - Debug 1 - Info 2 - Warning 3 - Error 4 - CriticalbooleanWhether the application has threadsafe enabled.booleanThe version id of the app to be run.booleanhasVm()optional bool vm = 22 [default = false];booleanoptional .apphosting.tools.devappserver2.VMConfig vm_config = 19;Methods inherited from interface com.google.protobuf.MessageLiteOrBuilder
isInitializedMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getDefaultInstanceForType, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Method Details
-
hasAppId
boolean hasAppId()The app id of the app to be run.
required bytes app_id = 1;- Returns:
- Whether the appId field is set.
-
getAppId
com.google.protobuf.ByteString getAppId()The app id of the app to be run.
required bytes app_id = 1;- Returns:
- The appId.
-
hasVersionId
boolean hasVersionId()The version id of the app to be run.
required bytes version_id = 2;- Returns:
- Whether the versionId field is set.
-
getVersionId
com.google.protobuf.ByteString getVersionId()The version id of the app to be run.
required bytes version_id = 2;- Returns:
- The versionId.
-
hasApplicationRoot
boolean hasApplicationRoot()The path to the root of the application.
required bytes application_root = 3;- Returns:
- Whether the applicationRoot field is set.
-
getApplicationRoot
com.google.protobuf.ByteString getApplicationRoot()The path to the root of the application.
required bytes application_root = 3;- Returns:
- The applicationRoot.
-
hasThreadsafe
boolean hasThreadsafe()Whether the application has threadsafe enabled.
optional bool threadsafe = 4 [default = false];- Returns:
- Whether the threadsafe field is set.
-
getThreadsafe
boolean getThreadsafe()Whether the application has threadsafe enabled.
optional bool threadsafe = 4 [default = false];- Returns:
- The threadsafe.
-
hasApiHost
boolean hasApiHost()The host name to which to connect to send API requests.
optional string api_host = 17 [default = "localhost"];- Returns:
- Whether the apiHost field is set.
-
getApiHost
String getApiHost()The host name to which to connect to send API requests.
optional string api_host = 17 [default = "localhost"];- Returns:
- The apiHost.
-
getApiHostBytes
com.google.protobuf.ByteString getApiHostBytes()The host name to which to connect to send API requests.
optional string api_host = 17 [default = "localhost"];- Returns:
- The bytes for apiHost.
-
hasApiPort
boolean hasApiPort()The port on which to connect to send API requests.
required int32 api_port = 5;- Returns:
- Whether the apiPort field is set.
-
getApiPort
int getApiPort()The port on which to connect to send API requests.
required int32 api_port = 5;- Returns:
- The apiPort.
-
getLibrariesList
Libraries enabled for the application.
repeated .apphosting.tools.devappserver2.Library libraries = 6; -
getLibraries
Libraries enabled for the application.
repeated .apphosting.tools.devappserver2.Library libraries = 6; -
getLibrariesCount
int getLibrariesCount()Libraries enabled for the application.
repeated .apphosting.tools.devappserver2.Library libraries = 6; -
getLibrariesOrBuilderList
List<? extends LibraryOrBuilder> getLibrariesOrBuilderList()Libraries enabled for the application.
repeated .apphosting.tools.devappserver2.Library libraries = 6; -
getLibrariesOrBuilder
Libraries enabled for the application.
repeated .apphosting.tools.devappserver2.Library libraries = 6; -
hasSkipFiles
boolean hasSkipFiles()A regex for files to skip.
optional string skip_files = 7 [default = "^$"];- Returns:
- Whether the skipFiles field is set.
-
getSkipFiles
String getSkipFiles()A regex for files to skip.
optional string skip_files = 7 [default = "^$"];- Returns:
- The skipFiles.
-
getSkipFilesBytes
com.google.protobuf.ByteString getSkipFilesBytes()A regex for files to skip.
optional string skip_files = 7 [default = "^$"];- Returns:
- The bytes for skipFiles.
-
hasStaticFiles
boolean hasStaticFiles()A regex for files used for static handlers.
optional string static_files = 8 [default = "^$"];- Returns:
- Whether the staticFiles field is set.
-
getStaticFiles
String getStaticFiles()A regex for files used for static handlers.
optional string static_files = 8 [default = "^$"];- Returns:
- The staticFiles.
-
getStaticFilesBytes
com.google.protobuf.ByteString getStaticFilesBytes()A regex for files used for static handlers.
optional string static_files = 8 [default = "^$"];- Returns:
- The bytes for staticFiles.
-
hasPythonConfig
boolean hasPythonConfig()optional .apphosting.tools.devappserver2.PythonConfig python_config = 14;- Returns:
- Whether the pythonConfig field is set.
-
getPythonConfig
PythonConfig getPythonConfig()optional .apphosting.tools.devappserver2.PythonConfig python_config = 14;- Returns:
- The pythonConfig.
-
getPythonConfigOrBuilder
PythonConfigOrBuilder getPythonConfigOrBuilder()optional .apphosting.tools.devappserver2.PythonConfig python_config = 14; -
hasPhpConfig
boolean hasPhpConfig()optional .apphosting.tools.devappserver2.PhpConfig php_config = 9;- Returns:
- Whether the phpConfig field is set.
-
getPhpConfig
PhpConfig getPhpConfig()optional .apphosting.tools.devappserver2.PhpConfig php_config = 9;- Returns:
- The phpConfig.
-
getPhpConfigOrBuilder
PhpConfigOrBuilder getPhpConfigOrBuilder()optional .apphosting.tools.devappserver2.PhpConfig php_config = 9; -
hasNodeConfig
boolean hasNodeConfig()optional .apphosting.tools.devappserver2.NodeConfig node_config = 26;- Returns:
- Whether the nodeConfig field is set.
-
getNodeConfig
NodeConfig getNodeConfig()optional .apphosting.tools.devappserver2.NodeConfig node_config = 26;- Returns:
- The nodeConfig.
-
getNodeConfigOrBuilder
NodeConfigOrBuilder getNodeConfigOrBuilder()optional .apphosting.tools.devappserver2.NodeConfig node_config = 26; -
hasJavaConfig
boolean hasJavaConfig()optional .apphosting.tools.devappserver2.JavaConfig java_config = 21;- Returns:
- Whether the javaConfig field is set.
-
getJavaConfig
JavaConfig getJavaConfig()optional .apphosting.tools.devappserver2.JavaConfig java_config = 21;- Returns:
- The javaConfig.
-
getJavaConfigOrBuilder
JavaConfigOrBuilder getJavaConfigOrBuilder()optional .apphosting.tools.devappserver2.JavaConfig java_config = 21; -
hasCustomConfig
boolean hasCustomConfig()optional .apphosting.tools.devappserver2.CustomConfig custom_config = 23;- Returns:
- Whether the customConfig field is set.
-
getCustomConfig
CustomConfig getCustomConfig()optional .apphosting.tools.devappserver2.CustomConfig custom_config = 23;- Returns:
- The customConfig.
-
getCustomConfigOrBuilder
CustomConfigOrBuilder getCustomConfigOrBuilder()optional .apphosting.tools.devappserver2.CustomConfig custom_config = 23; -
hasGoConfig
boolean hasGoConfig()optional .apphosting.tools.devappserver2.GoConfig go_config = 25;- Returns:
- Whether the goConfig field is set.
-
getGoConfig
GoConfig getGoConfig()optional .apphosting.tools.devappserver2.GoConfig go_config = 25;- Returns:
- The goConfig.
-
getGoConfigOrBuilder
GoConfigOrBuilder getGoConfigOrBuilder()optional .apphosting.tools.devappserver2.GoConfig go_config = 25; -
getEnvironList
Extra user-specified environment variables.
repeated .apphosting.tools.devappserver2.Environ environ = 10; -
getEnviron
Extra user-specified environment variables.
repeated .apphosting.tools.devappserver2.Environ environ = 10; -
getEnvironCount
int getEnvironCount()Extra user-specified environment variables.
repeated .apphosting.tools.devappserver2.Environ environ = 10; -
getEnvironOrBuilderList
List<? extends EnvironOrBuilder> getEnvironOrBuilderList()Extra user-specified environment variables.
repeated .apphosting.tools.devappserver2.Environ environ = 10; -
getEnvironOrBuilder
Extra user-specified environment variables.
repeated .apphosting.tools.devappserver2.Environ environ = 10; -
hasCloudSqlConfig
boolean hasCloudSqlConfig()optional .apphosting.tools.devappserver2.CloudSQL cloud_sql_config = 11;- Returns:
- Whether the cloudSqlConfig field is set.
-
getCloudSqlConfig
CloudSQL getCloudSqlConfig()optional .apphosting.tools.devappserver2.CloudSQL cloud_sql_config = 11;- Returns:
- The cloudSqlConfig.
-
getCloudSqlConfigOrBuilder
CloudSQLOrBuilder getCloudSqlConfigOrBuilder()optional .apphosting.tools.devappserver2.CloudSQL cloud_sql_config = 11; -
hasDatacenter
boolean hasDatacenter()required string datacenter = 12;- Returns:
- Whether the datacenter field is set.
-
getDatacenter
String getDatacenter()required string datacenter = 12;- Returns:
- The datacenter.
-
getDatacenterBytes
com.google.protobuf.ByteString getDatacenterBytes()required string datacenter = 12;- Returns:
- The bytes for datacenter.
-
hasInstanceId
boolean hasInstanceId()required string instance_id = 13;- Returns:
- Whether the instanceId field is set.
-
getInstanceId
String getInstanceId()required string instance_id = 13;- Returns:
- The instanceId.
-
getInstanceIdBytes
com.google.protobuf.ByteString getInstanceIdBytes()required string instance_id = 13;- Returns:
- The bytes for instanceId.
-
hasStderrLogLevel
boolean hasStderrLogLevel()The logging level at which logs should be written to stderr: 0 - Debug 1 - Info 2 - Warning 3 - Error 4 - Critical
optional int64 stderr_log_level = 15 [default = 1];- Returns:
- Whether the stderrLogLevel field is set.
-
getStderrLogLevel
long getStderrLogLevel()The logging level at which logs should be written to stderr: 0 - Debug 1 - Info 2 - Warning 3 - Error 4 - Critical
optional int64 stderr_log_level = 15 [default = 1];- Returns:
- The stderrLogLevel.
-
hasAuthDomain
boolean hasAuthDomain()required string auth_domain = 16;- Returns:
- Whether the authDomain field is set.
-
getAuthDomain
String getAuthDomain()required string auth_domain = 16;- Returns:
- The authDomain.
-
getAuthDomainBytes
com.google.protobuf.ByteString getAuthDomainBytes()required string auth_domain = 16;- Returns:
- The bytes for authDomain.
-
hasMaxInstances
boolean hasMaxInstances()optional int32 max_instances = 18;- Returns:
- Whether the maxInstances field is set.
-
getMaxInstances
int getMaxInstances()optional int32 max_instances = 18;- Returns:
- The maxInstances.
-
hasVmConfig
boolean hasVmConfig()optional .apphosting.tools.devappserver2.VMConfig vm_config = 19;- Returns:
- Whether the vmConfig field is set.
-
getVmConfig
VMConfig getVmConfig()optional .apphosting.tools.devappserver2.VMConfig vm_config = 19;- Returns:
- The vmConfig.
-
getVmConfigOrBuilder
VMConfigOrBuilder getVmConfigOrBuilder()optional .apphosting.tools.devappserver2.VMConfig vm_config = 19; -
hasServerPort
boolean hasServerPort()The port of the cloud SDK development server.
optional int32 server_port = 20;- Returns:
- Whether the serverPort field is set.
-
getServerPort
int getServerPort()The port of the cloud SDK development server.
optional int32 server_port = 20;- Returns:
- The serverPort.
-
hasVm
boolean hasVm()optional bool vm = 22 [default = false];- Returns:
- Whether the vm field is set.
-
getVm
boolean getVm()optional bool vm = 22 [default = false];- Returns:
- The vm.
-
getGrpcApisList
repeated string grpc_apis = 24;- Returns:
- A list containing the grpcApis.
-
getGrpcApisCount
int getGrpcApisCount()repeated string grpc_apis = 24;- Returns:
- The count of grpcApis.
-
getGrpcApis
repeated string grpc_apis = 24;- Parameters:
index- The index of the element to return.- Returns:
- The grpcApis at the given index.
-
getGrpcApisBytes
com.google.protobuf.ByteString getGrpcApisBytes(int index) repeated string grpc_apis = 24;- Parameters:
index- The index of the value to return.- Returns:
- The bytes of the grpcApis at the given index.
-