Class PhpConfig
java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessageV3
com.google.appengine.tools.development.proto.PhpConfig
- All Implemented Interfaces:
PhpConfigOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
public final class PhpConfig
extends com.google.protobuf.GeneratedMessageV3
implements PhpConfigOrBuilder
Runtime configuration required specifically for the PHP runtime.Protobuf type
apphosting.tools.devappserver2.PhpConfig- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classRuntime configuration required specifically for the PHP runtime.Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageType extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage,BuilderType extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageType, BuilderType>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageType extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageType extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessageLite.InternalOneOfEnum -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intstatic final intstatic final com.google.protobuf.Parser<PhpConfig>Deprecated.static final intstatic final intstatic final intstatic final intstatic final intFields inherited from class com.google.protobuf.GeneratedMessageV3
alwaysUseFieldBuilders, unknownFieldsFields inherited from class com.google.protobuf.AbstractMessage
memoizedSizeFields inherited from class com.google.protobuf.AbstractMessageLite
memoizedHashCode -
Method Summary
Modifier and TypeMethodDescriptionbooleanstatic PhpConfigstatic final com.google.protobuf.Descriptors.DescriptorbooleanEnable interactive debugging using XDebug.com.google.protobuf.ByteStringThe path to the GAE PHP extension that should be loaded.com.google.protobuf.Parser<PhpConfig>com.google.protobuf.ByteStringPath to the composer pharcom.google.protobuf.ByteStringThe path to the PHP executable that should be used.com.google.protobuf.ByteStringPaths to add to LD_LIBRARY_PATH for PHPcom.google.protobuf.ByteStringThe version of PHP executable.intfinal com.google.protobuf.UnknownFieldSetcom.google.protobuf.ByteStringThe path to the xdebug extension that should be loaded.booleanEnable interactive debugging using XDebug.booleanThe path to the GAE PHP extension that should be loaded.inthashCode()booleanPath to the composer pharbooleanThe path to the PHP executable that should be used.booleanPaths to add to LD_LIBRARY_PATH for PHPbooleanThe version of PHP executable.booleanThe path to the xdebug extension that should be loaded.protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTablefinal booleanstatic PhpConfig.Builderstatic PhpConfig.BuildernewBuilder(PhpConfig prototype) protected PhpConfig.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent) protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused) static PhpConfigparseDelimitedFrom(InputStream input) static PhpConfigparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) static PhpConfigparseFrom(byte[] data) static PhpConfigparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) static PhpConfigparseFrom(com.google.protobuf.ByteString data) static PhpConfigparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) static PhpConfigparseFrom(com.google.protobuf.CodedInputStream input) static PhpConfigparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) static PhpConfigparseFrom(InputStream input) static PhpConfigparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) static PhpConfigparseFrom(ByteBuffer data) static PhpConfigparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) static com.google.protobuf.Parser<PhpConfig>parser()voidwriteTo(com.google.protobuf.CodedOutputStream output) Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, isStringEmpty, makeExtensionsImmutable, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTagMethods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashFields, mutableCopy, toStringMethods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeToMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface com.google.protobuf.MessageLite
toByteArray, toByteString, writeDelimitedTo, writeToMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof
-
Field Details
-
PHP_EXECUTABLE_PATH_FIELD_NUMBER
public static final int PHP_EXECUTABLE_PATH_FIELD_NUMBER- See Also:
-
ENABLE_DEBUGGER_FIELD_NUMBER
public static final int ENABLE_DEBUGGER_FIELD_NUMBER- See Also:
-
GAE_EXTENSION_PATH_FIELD_NUMBER
public static final int GAE_EXTENSION_PATH_FIELD_NUMBER- See Also:
-
XDEBUG_EXTENSION_PATH_FIELD_NUMBER
public static final int XDEBUG_EXTENSION_PATH_FIELD_NUMBER- See Also:
-
PHP_VERSION_FIELD_NUMBER
public static final int PHP_VERSION_FIELD_NUMBER- See Also:
-
PHP_LIBRARY_PATH_FIELD_NUMBER
public static final int PHP_LIBRARY_PATH_FIELD_NUMBER- See Also:
-
PHP_COMPOSER_PATH_FIELD_NUMBER
public static final int PHP_COMPOSER_PATH_FIELD_NUMBER- See Also:
-
PARSER
Deprecated.
-
-
Method Details
-
newInstance
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() -
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
hasPhpExecutablePath
public boolean hasPhpExecutablePath()The path to the PHP executable that should be used.
optional bytes php_executable_path = 1;- Specified by:
hasPhpExecutablePathin interfacePhpConfigOrBuilder- Returns:
- Whether the phpExecutablePath field is set.
-
getPhpExecutablePath
public com.google.protobuf.ByteString getPhpExecutablePath()The path to the PHP executable that should be used.
optional bytes php_executable_path = 1;- Specified by:
getPhpExecutablePathin interfacePhpConfigOrBuilder- Returns:
- The phpExecutablePath.
-
hasEnableDebugger
public boolean hasEnableDebugger()Enable interactive debugging using XDebug.
required bool enable_debugger = 3;- Specified by:
hasEnableDebuggerin interfacePhpConfigOrBuilder- Returns:
- Whether the enableDebugger field is set.
-
getEnableDebugger
public boolean getEnableDebugger()Enable interactive debugging using XDebug.
required bool enable_debugger = 3;- Specified by:
getEnableDebuggerin interfacePhpConfigOrBuilder- Returns:
- The enableDebugger.
-
hasGaeExtensionPath
public boolean hasGaeExtensionPath()The path to the GAE PHP extension that should be loaded.
optional bytes gae_extension_path = 4;- Specified by:
hasGaeExtensionPathin interfacePhpConfigOrBuilder- Returns:
- Whether the gaeExtensionPath field is set.
-
getGaeExtensionPath
public com.google.protobuf.ByteString getGaeExtensionPath()The path to the GAE PHP extension that should be loaded.
optional bytes gae_extension_path = 4;- Specified by:
getGaeExtensionPathin interfacePhpConfigOrBuilder- Returns:
- The gaeExtensionPath.
-
hasXdebugExtensionPath
public boolean hasXdebugExtensionPath()The path to the xdebug extension that should be loaded.
optional bytes xdebug_extension_path = 5;- Specified by:
hasXdebugExtensionPathin interfacePhpConfigOrBuilder- Returns:
- Whether the xdebugExtensionPath field is set.
-
getXdebugExtensionPath
public com.google.protobuf.ByteString getXdebugExtensionPath()The path to the xdebug extension that should be loaded.
optional bytes xdebug_extension_path = 5;- Specified by:
getXdebugExtensionPathin interfacePhpConfigOrBuilder- Returns:
- The xdebugExtensionPath.
-
hasPhpVersion
public boolean hasPhpVersion()The version of PHP executable.
optional bytes php_version = 6;- Specified by:
hasPhpVersionin interfacePhpConfigOrBuilder- Returns:
- Whether the phpVersion field is set.
-
getPhpVersion
public com.google.protobuf.ByteString getPhpVersion()The version of PHP executable.
optional bytes php_version = 6;- Specified by:
getPhpVersionin interfacePhpConfigOrBuilder- Returns:
- The phpVersion.
-
hasPhpLibraryPath
public boolean hasPhpLibraryPath()Paths to add to LD_LIBRARY_PATH for PHP
optional bytes php_library_path = 7;- Specified by:
hasPhpLibraryPathin interfacePhpConfigOrBuilder- Returns:
- Whether the phpLibraryPath field is set.
-
getPhpLibraryPath
public com.google.protobuf.ByteString getPhpLibraryPath()Paths to add to LD_LIBRARY_PATH for PHP
optional bytes php_library_path = 7;- Specified by:
getPhpLibraryPathin interfacePhpConfigOrBuilder- Returns:
- The phpLibraryPath.
-
hasPhpComposerPath
public boolean hasPhpComposerPath()Path to the composer phar
optional bytes php_composer_path = 8;- Specified by:
hasPhpComposerPathin interfacePhpConfigOrBuilder- Returns:
- Whether the phpComposerPath field is set.
-
getPhpComposerPath
public com.google.protobuf.ByteString getPhpComposerPath()Path to the composer phar
optional bytes php_composer_path = 8;- Specified by:
getPhpComposerPathin interfacePhpConfigOrBuilder- Returns:
- The phpComposerPath.
-
isInitialized
public final boolean isInitialized()- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static PhpConfig parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static PhpConfig parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static PhpConfig parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static PhpConfig parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static PhpConfig parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static PhpConfig parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
- Throws:
IOException
-
parseFrom
public static PhpConfig parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
parseDelimitedFrom
- Throws:
IOException
-
parseDelimitedFrom
public static PhpConfig parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
parseFrom
- Throws:
IOException
-
parseFrom
public static PhpConfig parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
newBuilderForType
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
-
newBuilder
-
toBuilder
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected PhpConfig.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent) - Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
-
parser
-
getParserForType
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-