Interface PythonConfigOrBuilder
- All Superinterfaces:
com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder
- All Known Implementing Classes:
PythonConfig,PythonConfig.Builder
public interface PythonConfigOrBuilder
extends com.google.protobuf.MessageOrBuilder
-
Method Summary
Modifier and TypeMethodDescriptionAn argument that will be provided to the script specified in startup_script.com.google.protobuf.ByteStringAn argument that will be provided to the script specified in startup_script.The path to a Python script that will be executed using execfile before the runtime executes user code.com.google.protobuf.ByteStringThe path to a Python script that will be executed using execfile before the runtime executes user code.booleanAn argument that will be provided to the script specified in startup_script.booleanThe path to a Python script that will be executed using execfile before the runtime executes user code.Methods inherited from interface com.google.protobuf.MessageLiteOrBuilder
isInitializedMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getDefaultInstanceForType, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Method Details
-
hasStartupScript
boolean hasStartupScript()The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Returns:
- Whether the startupScript field is set.
-
getStartupScript
String getStartupScript()The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Returns:
- The startupScript.
-
getStartupScriptBytes
com.google.protobuf.ByteString getStartupScriptBytes()The path to a Python script that will be executed using execfile before the runtime executes user code. Meant for tools such as debuggers.
optional string startup_script = 1;- Returns:
- The bytes for startupScript.
-
hasStartupArgs
boolean hasStartupArgs()An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Returns:
- Whether the startupArgs field is set.
-
getStartupArgs
String getStartupArgs()An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Returns:
- The startupArgs.
-
getStartupArgsBytes
com.google.protobuf.ByteString getStartupArgsBytes()An argument that will be provided to the script specified in startup_script.
optional string startup_args = 2;- Returns:
- The bytes for startupArgs.
-