Class EnhancerTask
java.lang.Object
org.apache.tools.ant.ProjectComponent
org.apache.tools.ant.Task
org.apache.tools.ant.taskdefs.Java
com.google.appengine.tools.enhancer.EnhancerTask
- All Implemented Interfaces:
Cloneable
public class EnhancerTask
extends org.apache.tools.ant.taskdefs.Java
An Ant task for ORM enhancement.
In order to use this task, users must install a taskdef in Ant:
<taskdef name="enhancer" classpathref="appengine-sdk-classpath"
classname="com.google.appengine.tools.development.enhancer.EnhancerTask"/>
Where appengine-sdk-classpath includes appengine-tools-api.jar.
Options for this task are documented on DataNucleus' web site.
-
Field Summary
Fields inherited from class org.apache.tools.ant.taskdefs.Java
redirector, redirectorElementFields inherited from class org.apache.tools.ant.Task
target, taskName, taskType, wrapperFields inherited from class org.apache.tools.ant.ProjectComponent
description, location, project -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidaddFileSet(org.apache.tools.ant.types.FileSet fs) Add a fileset.voidexecute()Execution methodgetDir()Gets the root dir for looking for filesprotected File[]getFiles()voidset API AdaptervoidsetCheckonly(boolean checkonly) Whether to just check the enhancement statevoidsetDestination(File destdir) set output directoryvoidSets the root dir for looking for filesvoidsetEnhancerName(String enhancer) Set the symbolic name of the ClassEnhancer to usevoidsetFileSuffixes(String suffixes) Set one or more file suffixes for the input files.voidExecutes this task only if the property is setvoidsetPersistenceUnit(String unit) Set the persistence-unit name to enhancevoidsetVerbose(boolean verbose) set verboseMethods inherited from class org.apache.tools.ant.taskdefs.Java
addAssertions, addConfiguredRedirector, addEnv, addSysproperty, addSyspropertyset, checkConfiguration, clearArgs, createArg, createBootclasspath, createClasspath, createJvmarg, createModulepath, createPermissions, createUpgrademodulepath, createWatchdog, executeJava, executeJava, getCommandLine, getSysProperties, handleErrorFlush, handleErrorOutput, handleFlush, handleInput, handleOutput, maybeSetResultPropertyValue, run, setAppend, setArgs, setClassname, setClasspath, setClasspathRef, setCloneVm, setDiscardError, setDiscardOutput, setError, setErrorProperty, setFailonerror, setFork, setInput, setInputString, setJar, setJvm, setJvmargs, setJVMVersion, setLogError, setMaxmemory, setModule, setModulepath, setModulepathRef, setNewenvironment, setOutput, setOutputproperty, setResultProperty, setSourceFile, setSpawn, setTimeout, setupRedirectorMethods inherited from class org.apache.tools.ant.Task
bindToOwner, getOwningTarget, getRuntimeConfigurableWrapper, getTaskName, getTaskType, getWrapper, init, isInvalid, log, log, log, log, maybeConfigure, perform, reconfigure, setOwningTarget, setRuntimeConfigurableWrapper, setTaskName, setTaskTypeMethods inherited from class org.apache.tools.ant.ProjectComponent
clone, getDescription, getLocation, getProject, setDescription, setLocation, setProject
-
Constructor Details
-
EnhancerTask
public EnhancerTask()Default constructor
-
-
Method Details
-
execute
public void execute() throws org.apache.tools.ant.BuildExceptionExecution method- Overrides:
executein classorg.apache.tools.ant.taskdefs.Java- Throws:
org.apache.tools.ant.BuildException- Thrown when an error occurs when processing the task
-
setCheckonly
public void setCheckonly(boolean checkonly) Whether to just check the enhancement state- Parameters:
checkonly- Whether to just check
-
setDestination
set output directory- Parameters:
destdir- output dir
-
setApi
set API Adapter- Parameters:
api- API Adapter
-
setEnhancerName
Set the symbolic name of the ClassEnhancer to use- Parameters:
enhancer- Class Enhancer to use
-
setPersistenceUnit
Set the persistence-unit name to enhance- Parameters:
unit- Name of the persistence-unit to enhance
-
setDir
Sets the root dir for looking for files- Overrides:
setDirin classorg.apache.tools.ant.taskdefs.Java- Parameters:
dir- the root dir
-
getDir
Gets the root dir for looking for files- Returns:
- the root dir
-
setFileSuffixes
Set one or more file suffixes for the input files. Suffixes are separated with a comma(,)- Parameters:
suffixes- the suffices
-
setVerbose
public void setVerbose(boolean verbose) set verbose- Parameters:
verbose- Whether to give verbose output
-
addFileSet
public void addFileSet(org.apache.tools.ant.types.FileSet fs) Add a fileset. @see ant manual- Parameters:
fs- the FileSet
-
getFiles
-
setIf
Executes this task only if the property is set
-